<?php

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Admin Class
 * 
 * Handles generic Admin functionality and AJAX requests.
 * 
 * @package WooCommerce - Social Login
 * @since 1.0.0
 */
class WOO_Slg_Admin {
	
	var $model, $scripts, $render;
	
	public function __construct() {
		
		global $woo_slg_model, $woo_slg_scripts,$woo_slg_render;
		
		$this->model = $woo_slg_model;
		$this->scripts = $woo_slg_scripts;
		$this->render = $woo_slg_render;
	}
	
	/**
	 * Register All need admin menu page
	 * 
	 * @package WooCommerce - Social Login
	 * @since 1.0.0
	 */
	public function woo_slg_admin_menu_pages() {
		 
		$woo_slg_social_login = add_submenu_page( 'woocommerce' , __( 'WooCommerce Social Login', 'wooslg' ), __( 'Social Login', 'wooslg' ), 'manage_options', 'woo-social-login', array( $this, 'woo_slg_social_login' ) ); 
	}
	
	/**
	 * Add Social Login Page
	 * 
	 * Handles to load social login 
	 * page to show social login register data
	 * 
	 * @package WooCommerce - Social Login
	 * @since 1.0.0
	 */
	public function woo_slg_social_login() {
		
		include_once( WOO_SLG_ADMIN . '/forms/woo-social-login-data.php' );
	}
	
	/**
	 * Pop Up On Editor
	 *
	 * Includes the pop up on the WordPress editor
	 *
	 * @package WooCommerce - Social Login
	 * @since 1.1.1
	 */
	public function woo_slg_shortcode_popup() {
		
		include_once( WOO_SLG_ADMIN . '/forms/woo-slg-admin-popup.php' );
	}
	
    /**
	 * Add notice if SSL is not enabled
	 *
	 * @package WooCommerce - Social Login
	 * @since 1.1.1
	 */
	public function woo_slg_admin_ssl_notice(){
		
		global $woo_slg_options;
		
		$woo_social_order = get_option( 'woo_social_order' );	
		
		foreach ( $woo_social_order as $provider ) {
			
			global ${"woo_slg_social_".$provider};
			
			if( $woo_slg_options['woo_slg_enable_'.$provider] == "yes" && isset(${"woo_slg_social_".$provider}->requires_ssl) && ${"woo_slg_social_".$provider}->requires_ssl) {			?>
			<div class="error">
        		<p><?php _e( 'WooCommerce Social Login : <b>'. $provider .'</b> requires SSL for authentication. ', 'wooslg' ); ?></p>
    		</div>
    
	<?php }
		}	
	}
    
    /**
	 * if cURL is not enabled then show notice
	 *
	 * @package WooCommerce - Social Login
	 * @since 1.5.6
	 */
    public function woo_slg_admin_curl_notice() {
        
        if( !extension_loaded('curl') ) { ?>
            <div class="error notice">
                <p>
                    <?php                     
                    echo sprintf( __( 'WooCommerce Social Login requires the %scURL%s PHP function to exist.  Contact your host or server administrator to configure and install the missing function.', 'wooslg' ),'<b>', '</b>' );                     
                    ?>
                </p>
            </div><?php
        }
    }
	
	/**
	 * Add 'Social Profiles' column to the Users admin table
	 *
	 * @package WooCommerce - Social Login
	 * @since 1.4.7
	 */
	public function woo_slg_add_user_columns ( $columns ) {
		
		return wps_array_insert_after( $columns, 'email', array( 'wps_social_login_profiles' => __( 'Primary Social Profile', 'wooslg' ) ) );
	}
	
	/**
	 * Render social profile icons in the 'Social Profiles' column of the Users admin table
	 *
	 * @package WooCommerce - Social Login
	 * @since 1.4.7
	 */
	public function woo_slg_user_column_values ( $output, $column_name, $user_id ) {
		
		if ( $column_name === 'wps_social_login_profiles' ) {
			
			$wps_user = get_user_by( 'id', $user_id );
			if ( !empty( $user_id ) && !empty( $wps_user ) ){
				
				$wps_user_soc_login_prof = get_user_meta( $user_id, 'woo_slg_social_user_connect_via', true );
				if ( !empty( $wps_user_soc_login_prof ) ) {
					
					$provider	= WOO_SLG_IMG_URL . "/" . $wps_user_soc_login_prof . "-provider.png";
					$output 	.= '<img src="' . $provider . '" >';
				} else {
					$output .= __( 'N/A', 'wooslg');
				}
			}
		}
		
		return $output;
	}
	
	
	/**
	 * Render social profile icons in the user edit screen
	 *
	 * @package WooCommerce - Social Login
	 * @since 1.4.8
	 */
	function woo_slg_show_user_profiles( $user ) { 

		$user_id = $user->ID;
		$primaryProfile = __( 'N/A', 'wooslg');

		// solved link profile not show on admin side,pass user id
		$linked_profiles = $this->render->woo_get_user_social_linked_profiles($user_id);
		
		//get primary social account type if exist
		$primary_social		= get_user_meta( $user_id, 'woo_slg_social_user_connect_via', true );		
		if ( !empty( $primary_social ) ) {					
				$provider	= WOO_SLG_IMG_URL . "/" . $primary_social . "-provider.png";
				$primaryProfile	= '<img src="' . $provider . '" >';
		}		
		?>
		
		<h2><?php _e( 'Social Profiles', 'wooslg' ); ?></h2>
			<table class="form-table">
				<tr>
					<th> <?php _e( 'Primary Social Profile', 'wooslg' ); ?></th>
					<td><?php echo $primaryProfile; ?></td>
				</tr>
				<tr>
					<th> <?php _e( 'Linked Social Profiles', 'wooslg' ); ?></th>
					<td>
					<?php
					$woo_linked_profiles = 0;
					if( !empty( $linked_profiles ) ) {
						
						foreach ( $linked_profiles as $profile => $value ) {
							if( $profile != $primary_social ) {
								$provider		= WOO_SLG_IMG_URL . "/" . $profile . "-provider.png";
								echo '<img src="'.$provider.'" class="woo-slg-linked-provider-image">';
								$woo_linked_profiles++;
							}
						}
					} 
					if( $woo_linked_profiles == 0) {
						_e( 'N/A', 'wooslg');
					}
					?>
					</td>
				</tr>
			</table>
	<?php
	}

	/**
	 * Function to generate and download system log report
	 *
	 * @package WooCommerce - Social Login
	 * @since 1.5.6
	 */
	public function woo_slg_generate_system_log(){

		// If post data is set
		if( !empty($_GET['tab']) && $_GET['tab'] == 'social-login' && !empty($_GET['woo_slg_gen_sys_log']) && $_GET['woo_slg_gen_sys_log'] == 1 ) {

			// Declare username array
			$username_arr = array(
                ''				=> __( 'Based on unique ID & random number', 'wooslg' ),
				'realname'		=> __( 'Based on real name', 'wooslg' ),
				'emailbased'	=> __( 'Based on email ID', 'wooslg' ),
				'realemailbased'	=> __( 'Actual email ID','wooslg')
            );

			// get all required options to show in system log
			$delete_option				 = get_option('woo_slg_delete_options');
			$enable_email_notification	 = get_option('woo_slg_enable_notification');
			$user_name 					 = get_option('woo_slg_base_reg_username');
			$is_enabled_login_page 		 = get_option('woo_slg_enable_login_page');
			$is_enabled_register_page 	 = get_option('woo_slg_enable_woo_register_page');
			$is_enabled_checkout_page	 = get_option('woo_slg_enable_on_checkout_page');
			$is_enabled_wp_login_page	 = get_option('woo_slg_enable_wp_login_page');
			$is_enabled_wp_register_page = get_option('woo_slg_enable_wp_register_page');
			$disp_thankyou_page			 = get_option('woo_slg_display_link_thank_you');

			// Open new file
		    $handle = fopen("social-login-system-report.txt", "w");

		    // Start writing data in our file
		    $log_data 			= '--- WPWeb Social Login Report Information ---';

		    // Declare woocommerce variables to use for getting system data
		    $system_status  	= new WC_REST_System_Status_Controller;
			$environment    	= $system_status->get_environment_info();
			$database         	= $system_status->get_database_info();
			$active_plugins   	= $system_status->get_active_plugins();
			$theme            	= $system_status->get_theme_info();

			// HTML for WordPress environment
			$log_data	.= "\n\n".__('--- WordPress Environment ---', 'wooslg');
			$log_data	.= "\n".__('Home URL: ', 'wooslg') . $environment['home_url'];
			$log_data	.= "\n".__('WorPress Version: ', 'wooslg') . $environment['wp_version'];
			$log_data	.= "\n".__('WooCommerce Version: ', 'wooslg') . $environment['version'];
			$log_data	.= "\n".__('WP Debug Mode: ', 'wooslg') . ( $environment['wp_debug_mode']? __('Yes', 'wooslg') : __('No', 'wooslg') );
			$log_data	.= "\n".__('WP cron: ', 'wooslg') . ( $environment['wp_cron'] ? __('Yes', 'wooslg') : __('No', 'wooslg') );

			// HTML for Server environment
			$log_data	.= "\n\n".__('--- Server Environment ---', 'wooslg');
			$log_data	.= "\n".__('PHP Version: ', 'wooslg') . $environment['php_version'];
			$log_data	.= "\n".__('WC Database Version: ', 'wooslg') . $database['wc_database_version'];
			$log_data	.= "\n".__('fsockopen/cURL: ', 'wooslg') . ( $environment['fsockopen_or_curl_enabled'] ? __('Yes', 'wooslg') : __('No', 'wooslg') );

			// HTML for Active plugins
			$log_data	.= "\n\n".__('--- Active Plugins ---', 'wooslg');
			foreach($active_plugins as $plugin){

				if ( ! empty( $plugin['name'] ) ) {
					$dirname = dirname( $plugin['plugin'] );
	
					// Link the plugin name to the plugin url if available.
					$plugin_name = esc_html( $plugin['name'] );
					
					$version_string = '';
					$network_string = '';
					if ( strstr( $plugin['url'], 'woothemes.com' ) || strstr( $plugin['url'], 'woocommerce.com' ) ) {
						if ( ! empty( $plugin['version_latest'] ) && version_compare( $plugin['version_latest'], $plugin['version'], '>' ) ) {
							/* translators: %s: plugin latest version */
							$version_string = ' &ndash; <strong style="color:red;">' . sprintf( esc_html__( '%s is available', 'wooslg' ), $plugin['version_latest'] ) . '</strong>';
						}
	
						if ( false != $plugin['network_activated'] ) {
							$network_string = ' &ndash; <strong style="color:black;">' . __( 'Network enabled', 'wooslg' ) . '</strong>';
						}
					}
					
					$log_data .= "\n" . $plugin_name . __( ' by ', 'wooslg' ) . $plugin['author_name'] . __(' - ', 'wooslg') . esc_html( $plugin['version'] ) . $version_string . $network_string;
				}
			}

			// HTML for Active theme
			$log_data .= "\n\n".__('--- Active Theme ---', 'wooslg');
			$log_data .= "\n" . __('Theme Name: ', 'wooslg') . $theme['name'];
			$log_data .= "\n" . __('Version: ') . $theme['version'];
			$log_data .= "\n" . __('Author URL: ') . $theme['author_url'];
			$log_data .= "\n" . __('Child theme: ') . ( $theme['is_child_theme'] ? __('Yes', 'wooslg') : __('No', 'wooslg') );

			// HTML for Plugin settings
			$log_data .= "\n\n" . __('--- Plugin Settings ---', 'wooslg');
			$log_data .= "\n" . __("Delete Option: ", 'wooslg') . ( !empty($delete_option) ? ucfirst($delete_option) : __('No', 'wooslg') );
			$log_data .= "\n" . __("Enable Email Notification: ", 'wooslg') . ( !empty($enable_email_notification) ? ucfirst($enable_email_notification) : __('No', 'wooslg') );
			$log_data .= "\n" . __("Autoregistered Usernames: ", 'wooslg') . $username_arr[$user_name];
			$log_data .= "\n" . __("Display Login button on WooCommerce login Page: ", 'wooslg') . ( !empty($is_enabled_login_page) ? ucfirst($is_enabled_login_page) : __('No', 'wooslg') );
			$log_data .= "\n" . __("Display Login button on WooCommerce Registration Page: ", 'wooslg') . ( !empty($is_enabled_register_page) ? ucfirst($is_enabled_register_page) : __('No', 'wooslg') );
			$log_data .= "\n" . __("Display Login button on WooCommerce Checkout Page: ", 'wooslg') . ( !empty($is_enabled_checkout_page) ? ucfirst($is_enabled_checkout_page) : __('No', 'wooslg') );
			$log_data .= "\n" . __("Display Login button on Wordpress default login Page: ", 'wooslg') . ( !empty($is_enabled_wp_login_page) ? ucfirst($is_enabled_wp_login_page) : __('No', 'wooslg') );
			$log_data .= "\n" . __("Display Login button on Wordpress default register Page: ", 'wooslg') . ( !empty($is_enabled_wp_register_page) ? ucfirst($is_enabled_wp_register_page) : __('No', 'wooslg') );
			$log_data .= "\n" . __("Display Link Your Account on thankyou page: ", 'wooslg') . ( !empty($disp_thankyou_page) ? ucfirst($disp_thankyou_page) : __('No', 'wooslg') );

		    fwrite($handle, $log_data);
		    fclose($handle);

		    header('Content-Type: application/octet-stream');
		    header('Content-Disposition: attachment; filename="'.basename('social-login-system-report.txt').'"');
		    header('Expires: 0');
		    header('Cache-Control: must-revalidate');
		    header('Pragma: public');
		    header('Content-Length: ' . filesize('social-login-system-report.txt'));
		    readfile('social-login-system-report.txt');
		    unlink("social-login-system-report.txt");
		    exit;
		}
	}
	
	/**
	 * Adding Hooks
	 * 
	 * @package WooCommerce - Social Login
	 * @since 1.0.0
	 */
	public function add_hooks() {
		
		//add admin menu pages
		add_action ( 'admin_menu', array( $this, 'woo_slg_admin_menu_pages' ) );
		
		// mark up for popup
		add_action( 'admin_footer-post.php', array( $this,'woo_slg_shortcode_popup' ) );
		add_action( 'admin_footer-post-new.php', array( $this,'woo_slg_shortcode_popup' ) );
		if(!is_ssl()){
			add_action( 'admin_notices', array( $this,'woo_slg_admin_ssl_notice' ) ); 
		}
        
        // check curl is enabled or not
        add_action( 'admin_notices', array( $this, 'woo_slg_admin_curl_notice' ) ); 
		
		// add social profiles column to the Users admin table
		add_filter( 'manage_users_columns',       array( $this, 'woo_slg_add_user_columns' ), 11 );
		add_filter( 'manage_users_custom_column', array( $this, 'woo_slg_user_column_values' ), 11, 3 );
		
		add_action( 'show_user_profile', array( $this, 'woo_slg_show_user_profiles' ) );
		add_action( 'edit_user_profile', array( $this, 'woo_slg_show_user_profiles' ) );

		// Add action to generate and download system report file
		add_action( 'admin_init', array( $this, 'woo_slg_generate_system_log' ) );
	}
}